StoryKit class

Inheritance

Constructors

StoryKit({Key? key, required List<Widget> stories, int initialIndex = 0, ValueChanged<int>? onIndexChange, Duration durationPerStory(int index)?, Color progressColor = Colors.blue, Color progressBackgroundColor = Colors.grey, Widget? backgroundImage, Color? wholeBackgroundColor, int? currentIndex, LinePositon? linePositon})
const

Properties

backgroundImage Widget?
final
currentIndex int?
final
durationPerStory Duration Function(int index)?
final
hashCode int
The hash code for this object.
no setterinherited
initialIndex int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
linePositon LinePositon?
final
onIndexChange ValueChanged<int>?
final
progressBackgroundColor Color
final
progressColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stories List<Widget>
final
wholeBackgroundColor Color?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() StoryKitState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited